@@ -1,15 +1,15 @@
 #!/usr/bin/env python
 
 import logging
-from itertools import combinations, permutations, chain
+from itertools import chain, combinations, permutations
 
 import networkx as nx
-from tqdm.auto import tqdm
 from joblib import Parallel, delayed
+from tqdm.auto import tqdm
 
 from pgmpy.base import PDAG
 from pgmpy.estimators import StructureEstimator
-from pgmpy.estimators.CITests import chi_square, pearsonr, independence_match
+from pgmpy.estimators.CITests import chi_square, independence_match, pearsonr
 from pgmpy.global_vars import SHOW_PROGRESS
 
 
@@ -25,7 +25,7 @@ class PC(StructureEstimator):
         Parameters
         ----------
         data: pandas DataFrame object
-            datafame object where each column represents one variable.  (If some
+            dataframe object where each column represents one variable.  (If some
             values in the data are missing the data cells should be set to
             `numpy.NaN`.  Note that pandas converts each column containing
             `numpy.NaN`s to dtype `float`.)
@@ -103,7 +103,7 @@ class PC(StructureEstimator):
 
         Returns
         -------
-        model: DAG-instance, PDAG-instance, or (networkx.UndirectedGraph, dict)
+        Estimated model: pgmpy.base.DAG, pgmpy.base.PDAG, or tuple(networkx.UndirectedGraph, dict)
                 The estimated model structure, can be a partially directed graph (PDAG)
                 or a fully directed graph (DAG), or (Undirected Graph, separating sets)
                 depending on the value of `return_type` argument.
@@ -162,7 +162,7 @@ class PC(StructureEstimator):
             )
         elif (ci_test in ("chi_square", "pearsonr")) and (self.data is None):
             raise ValueError(
-                "For using Chi Square or Pearsonr, data arguement must be specified"
+                "For using Chi Square or Pearsonr, data argument must be specified"
             )
 
         # Step 1: Run the PC algorithm to build the skeleton and get the separating sets.
@@ -213,7 +213,7 @@ class PC(StructureEstimator):
         have to admit a faithful BN representation. This is the case if
         they are obtained as a set of d-seperations of some Bayesian network or
         if the independence assertions are closed under the semi-graphoid axioms.
-        Otherwise the procedure may fail to identify the correct structure.
+        Otherwise, the procedure may fail to identify the correct structure.
 
         Parameters
         ----------
@@ -248,7 +248,7 @@ class PC(StructureEstimator):
         >>> skel, sep_sets = PC(independencies=ind).build_skeleton("ABCD", ind)
         >>> print(skel.edges())
         [('A', 'D'), ('B', 'D'), ('C', 'D')]
-        >>> # build skeleton from d-seperations of DAG:
+        >>> # build skeleton from d-separations of DAG:
         ... model = DAG([('A', 'C'), ('B', 'C'), ('B', 'D'), ('C', 'E')])
         >>> skel, sep_sets = PC.build_skeleton(model.nodes(), model.get_independencies())
         >>> print(skel.edges())
@@ -312,8 +312,8 @@ class PC(StructureEstimator):
                 neighbors = {node: set(graph[node]) for node in graph.nodes()}
                 for (u, v) in graph.edges():
                     for separating_set in chain(
-                        combinations(set(graph.neighbors(u)) - set([v]), lim_neighbors),
-                        combinations(set(graph.neighbors(v)) - set([u]), lim_neighbors),
+                        combinations(set(neighbors[u]) - set([v]), lim_neighbors),
+                        combinations(set(neighbors[v]) - set([u]), lim_neighbors),
                     ):
                         # If a conditioning set exists remove the edge, store the
                         # separating set and move on to finding conditioning set for next edge.
@@ -400,7 +400,7 @@ class PC(StructureEstimator):
 
         Returns
         -------
-        pdag: DAG
+        Model after edge orientation: pgmpy.base.DAG
             An estimate for the DAG pattern of the BN underlying the data. The
             graph might contain some nodes with both-way edges (X->Y and Y->X).
             Any completion by (removing one of the both-way edges for each such
