@@ -90,8 +90,6 @@ class Mplp(Inference):
 
         # Assignment of the nodes that results in the "maximum" integral value of the primal objective
         self.best_assignment = {}
-        # Results of the "maximum" integral value of the primal objective.
-        self.best_decoded_result = {}
         # This sets the minimum width between the dual objective decrements. Default value = 0.0002. This can be
         # changed in the map_query() method.
         self.dual_threshold = 0.0002
@@ -113,7 +111,7 @@ class Mplp(Inference):
             collection of intersection of all pairs of cluster variables. For eg: \{\{C_1 \cap C_2\}, \{C_2 \cap C_3\}, \{C_3 \cap C_1\} \} for clusters C_1, C_2 & C_3.
 
         cluster_potential: DiscreteFactor
-            Each cluster has a initial probability distribution provided beforehand.
+            Each cluster has an initial probability distribution provided beforehand.
         """
 
         def __init__(self, intersection_set_variables, cluster_potential):
@@ -403,7 +401,7 @@ class Mplp(Inference):
 
     def _run_mplp(self, no_iterations):
         """
-        Updates messages until either Mplp converges or if doesn't converges; halts after no_iterations.
+        Updates messages until either Mplp converges or if it doesn't converge; halts after no_iterations.
 
         Parameters
         --------
@@ -458,7 +456,7 @@ class Mplp(Inference):
             # add triplets that are yet not added.
             add_triplets = []
             for triplet_number in range(len(sorted_scores)):
-                # At once, we can add atmost 5 triplets
+                # At once, we can add at most 5 triplets
                 if triplet_number >= max_triplets:
                     break
                 add_triplets.append(sorted_scores.pop())
@@ -582,12 +580,4 @@ class Mplp(Inference):
         # If triplets are to be used for the tightening, we proceed as follows
         if tighten_triplet:
             self._tighten_triplet(max_iterations, later_iter, max_triplets, prolong)
-        # Get the best result from the best assignment
-        self.best_decoded_result = {
-            factor.scope()[0]: factor.values[
-                self.best_assignment[frozenset(factor.scope())]
-            ]
-            for factor in self.model.factors
-            if len(factor.scope()) == 1
-        }
-        return self.best_decoded_result
+        return {list(key)[0]: val for key, val in self.best_assignment.items()}
