@@ -1,9 +1,11 @@
+from .BayesianNetwork import BayesianNetwork
 from .BayesianModel import BayesianModel
 from .ClusterGraph import ClusterGraph
 from .DynamicBayesianNetwork import DynamicBayesianNetwork
 from .FactorGraph import FactorGraph
 from .JunctionTree import JunctionTree
 from .MarkovChain import MarkovChain
+from .MarkovNetwork import MarkovNetwork
 from .MarkovModel import MarkovModel
 from .NaiveBayes import NaiveBayes
 from .NoisyOrModel import NoisyOrModel
@@ -12,7 +14,9 @@ from .SEM import SEMGraph, SEMAlg, SEM
 
 __all__ = [
     "BayesianModel",
+    "BayesianNetwork",
     "NoisyOrModel",
+    "MarkovNetwork",
     "MarkovModel",
     "FactorGraph",
     "JunctionTree",
