@@ -7,13 +7,13 @@ from math import sqrt
 import numpy as np
 from tqdm.auto import tqdm
 
-from pgmpy.utils import _check_1d_array_object, _check_length_equal
 from pgmpy.sampling import (
-    LeapFrog,
-    BaseSimulateHamiltonianDynamics,
     BaseGradLogPDF,
+    BaseSimulateHamiltonianDynamics,
+    LeapFrog,
     _return_samples,
 )
+from pgmpy.utils import _check_1d_array_object, _check_length_equal
 
 
 class HamiltonianMC(object):
@@ -112,9 +112,9 @@ class HamiltonianMC(object):
         Temporary method to fix issue in numpy 0.12 #852
         """
         if a == 1:
-            return (acceptance_prob ** a) > (1 / (2 ** a))
+            return (acceptance_prob**a) > (1 / (2**a))
         else:
-            return (1 / (acceptance_prob ** a)) > (2 ** (-a))
+            return (1 / (acceptance_prob**a)) > (2 ** (-a))
 
     def _find_reasonable_stepsize(self, position, stepsize_app=1):
         """
@@ -145,7 +145,7 @@ class HamiltonianMC(object):
         condition = self._get_condition(acceptance_prob, a)
 
         while condition:
-            stepsize_app = (2 ** a) * stepsize_app
+            stepsize_app = (2**a) * stepsize_app
 
             position_bar, momentum_bar, _ = self.simulate_dynamics(
                 self.model, position, momentum, stepsize_app, self.grad_log_pdf
@@ -166,7 +166,7 @@ class HamiltonianMC(object):
         # Resampling momentum
         momentum = np.reshape(np.random.normal(0, 1, len(position)), position.shape)
 
-        # position_m here will be the previous sampled value of position
+        # position_m here will be the previously sampled value of position
         position_bar, momentum_bar = position.copy(), momentum
 
         # Number of steps L to simulate dynamics
@@ -192,7 +192,7 @@ class HamiltonianMC(object):
         # Metropolis acceptance probability
         alpha = min(1, acceptance_prob)
 
-        # Accept or reject the new proposed value of position, i.e position_bar
+        # Accept or reject the new proposed value of position, i.e. position_bar
         if np.random.rand() < alpha:
             position = position_bar.copy()
             self.accepted_proposals += 1.0
@@ -286,7 +286,7 @@ class HamiltonianMC(object):
         lsteps = int(max(1, round(trajectory_length / stepsize, 0)))
         for i in tqdm(range(1, num_samples)):
 
-            # Genrating sample
+            # Generating sample
             position_m, _ = self._sample(
                 position_m, trajectory_length, stepsize, lsteps
             )
@@ -527,7 +527,7 @@ class HamiltonianMCDA(HamiltonianMC):
         if stepsize is None:
             stepsize = self._find_reasonable_stepsize(initial_pos)
 
-        if num_adapt <= 1:  # Return samples genrated using Simple HMC algorithm
+        if num_adapt <= 1:  # Return samples generated using Simple HMC algorithm
             return HamiltonianMC.sample(
                 self, initial_pos, num_samples, trajectory_length, stepsize
             )
@@ -548,7 +548,7 @@ class HamiltonianMCDA(HamiltonianMC):
 
         for i in tqdm(range(1, num_samples)):
 
-            # Genrating sample
+            # Generating sample
             position_m, alpha = self._sample(position_m, trajectory_length, stepsize)
             samples[i] = tuple(position_m)
 
